@@ -3,7 +3,7 @@
  *
  * EventDance, Peer-to-peer IPC library <http://eventdance.org>
  *
- * Copyright (C) 2009/2010, Igalia S.L.
+ * Copyright (C) 2009-2013, Igalia S.L.
  *
  * Authors:
  *   Eduardo Lima Mitev <elima@igalia.com>
@@ -23,9 +23,9 @@
 #ifndef __EVD_CONNECTION_POOL_H__
 #define __EVD_CONNECTION_POOL_H__
 
-#include <evd-io-stream-group.h>
-
-#include <evd-connection.h>
+#include "evd-io-stream-group.h"
+#include "evd-connection.h"
+#include "evd-tls-credentials.h"
 
 G_BEGIN_DECLS
 
@@ -82,6 +82,14 @@ EvdConnection         *evd_connection_pool_get_connection_finish    (EvdConnecti
 gboolean               evd_connection_pool_recycle                  (EvdConnectionPool *self,
                                                                      EvdConnection     *conn);
 
+void                   evd_connection_pool_set_tls_autostart        (EvdConnectionPool *self,
+                                                                     gboolean           autostart);
+gboolean               evd_connection_pool_get_tls_autostart        (EvdConnectionPool *self);
+
+void                   evd_connection_pool_set_tls_credentials      (EvdConnectionPool *self,
+                                                                     EvdTlsCredentials *credentials);
+EvdTlsCredentials     *evd_connection_pool_get_tls_credentials      (EvdConnectionPool *self);
+
 G_END_DECLS
 
 #endif /* __EVD_CONNECTION_POOL_H__ */
