@@ -3,7 +3,7 @@
  *
  * EventDance, Peer-to-peer IPC library <http://eventdance.org>
  *
- * Copyright (C) 2009/2010, Igalia S.L.
+ * Copyright (C) 2009-2013, Igalia S.L.
  *
  * Authors:
  *   Eduardo Lima Mitev <elima@igalia.com>
@@ -25,7 +25,7 @@
 
 #include <glib-object.h>
 
-#include <evd-transport.h>
+#include "evd-transport.h"
 
 G_BEGIN_DECLS
 
