@@ -3,7 +3,7 @@
  *
  * EventDance, Peer-to-peer IPC library <http://eventdance.org>
  *
- * Copyright (C) 2009-2012, Igalia S.L.
+ * Copyright (C) 2009-2013, Igalia S.L.
  *
  * Authors:
  *   Eduardo Lima Mitev <elima@igalia.com>
@@ -153,6 +153,17 @@ evd_http_connection_dispose (GObject *obj)
       self->priv->current_request = NULL;
     }
 
+  if (self->priv->async_result != NULL)
+    {
+      g_simple_async_result_set_error (self->priv->async_result,
+                                       G_IO_ERROR,
+                                       G_IO_ERROR_FAILED,
+                                       "HTTP connection destroyed while an operation was pending");
+      g_simple_async_result_complete (self->priv->async_result);
+      g_object_unref (self->priv->async_result);
+      self->priv->async_result = NULL;
+    }
+
   G_OBJECT_CLASS (evd_http_connection_parent_class)->dispose (obj);
 }
 
@@ -280,6 +291,7 @@ evd_http_connection_on_read_headers (EvdHttpConnection *self,
         {
           EvdHttpRequest *request;
           SoupURI *uri;
+          const gchar *conn_header;
 
           uri = evd_http_connection_build_uri (self, path, headers);
 
@@ -301,9 +313,14 @@ evd_http_connection_on_read_headers (EvdHttpConnection *self,
           self->priv->content_len =
             soup_message_headers_get_content_length (headers);
 
+          /* detect if is keep-alive */
+          conn_header = soup_message_headers_get_one (headers, "Connection");
+
           self->priv->keepalive =
-            g_strcmp0 (soup_message_headers_get_one (headers, "Connection"),
-                       "keep-alive") == 0;
+            (version == SOUP_HTTP_1_0 && conn_header != NULL &&
+             g_strstr_len (conn_header, -1, "keep-alive") != NULL) ||
+            (version == SOUP_HTTP_1_1 && conn_header != NULL &&
+             g_strstr_len (conn_header, -1, "close") == NULL);
         }
       else
         {
@@ -416,21 +433,24 @@ evd_http_connection_on_read_headers_block (GObject      *obj,
           void *unread_buf;
           gsize unread_size;
 
-          /* unread data beyond HTTP headers, back to the stream */
-          unread_buf = self->priv->buf->str + pos;
           unread_size = self->priv->buf->len - pos;
-
-          if (evd_buffered_input_stream_unread (EVD_BUFFERED_INPUT_STREAM (obj),
-                                                unread_buf,
-                                                unread_size,
-                                                NULL,
-                                                &error) >= 0)
+          if (unread_size > 0)
             {
-              g_string_set_size (self->priv->buf, pos);
+              /* unread data beyond HTTP headers, back to the stream */
+              unread_buf = self->priv->buf->str + pos;
 
-              evd_http_connection_on_read_headers (self, self->priv->buf);
+              if (evd_buffered_input_stream_unread (EVD_BUFFERED_INPUT_STREAM (obj),
+                                                    unread_buf,
+                                                    unread_size,
+                                                    NULL,
+                                                    &error) >= 0)
+                {
+                  g_string_set_size (self->priv->buf, pos);
+                }
             }
 
+          evd_http_connection_on_read_headers (self, self->priv->buf);
+
           self->priv->last_headers_pos = 0;
           g_string_set_size (self->priv->buf, 0);
         }
@@ -1320,8 +1340,10 @@ evd_http_connection_respond (EvdHttpConnection   *self,
   else
     _headers = headers;
 
-  if (close_after)
+  if (close_after || ! self->priv->keepalive)
     soup_message_headers_replace (_headers, "Connection", "close");
+  else
+    soup_message_headers_replace (_headers, "Connection", "keep-alive");
 
   soup_message_headers_set_content_length (_headers, size);
 
@@ -1439,6 +1461,22 @@ evd_http_connection_redirect (EvdHttpConnection  *self,
   return result;
 }
 
+/**
+ * evd_http_connection_set_keepalive:
+ * @self: The #EvdHttpConnection
+ * @keepalive: %TRUE or %FALSE
+ *
+ * Manually sets the keepalive flag, overriding the internal state obtained from
+ * HTTP headers.
+ **/
+void
+evd_http_connection_set_keepalive (EvdHttpConnection *self, gboolean keepalive)
+{
+  g_return_if_fail (EVD_IS_HTTP_CONNECTION (self));
+
+  self->priv->keepalive = keepalive;
+}
+
 gboolean
 evd_http_connection_get_keepalive (EvdHttpConnection *self)
 {
