@@ -3,7 +3,7 @@
  *
  * EventDance, Peer-to-peer IPC library <http://eventdance.org>
  *
- * Copyright (C) 2009-2012, Igalia S.L.
+ * Copyright (C) 2009-2013, Igalia S.L.
  *
  * Authors:
  *   Eduardo Lima Mitev <elima@igalia.com>
@@ -27,7 +27,7 @@
 #include <gio/gio.h>
 #include <json-glib/json-glib.h>
 
-#include <evd-transport.h>
+#include "evd-transport.h"
 
 G_BEGIN_DECLS
 
@@ -133,6 +133,11 @@ gboolean             evd_jsonrpc_respond_error                (EvdJsonrpc  *self
                                                                JsonNode    *json_error,
                                                                gpointer     context,
                                                                GError     **error);
+gboolean             evd_jsonrpc_respond_from_error           (EvdJsonrpc  *self,
+                                                               guint        invocation_id,
+                                                               GError      *result_error,
+                                                               gpointer     context,
+                                                               GError     **error);
 
 void                 evd_jsonrpc_use_transport                (EvdJsonrpc   *self,
                                                                EvdTransport *transport);
