@@ -31,6 +31,10 @@
 
 #include "evd-socket.h"
 
+#ifdef HAVE_GIO_UNIX
+#include <gio/gunixsocketaddress.h>
+#endif
+
 #include "evd-utils.h"
 #include "evd-marshal.h"
 #include "evd-error.h"
@@ -328,8 +332,6 @@ evd_socket_finalize (GObject *obj)
   g_object_unref (self->priv->poll);
 
   G_OBJECT_CLASS (evd_socket_parent_class)->finalize (obj);
-
-  //  g_debug ("[EvdSocket 0x%X] Socket finalized", (guintptr) obj);
 }
 
 static void
@@ -1224,7 +1226,13 @@ evd_socket_get_remote_address (EvdSocket  *self, GError **error)
   g_return_val_if_fail (EVD_IS_SOCKET (self), NULL);
 
   if (self->priv->socket == NULL)
-    return NULL;
+    {
+      g_set_error (error,
+                   G_IO_ERROR,
+                   G_IO_ERROR_NOT_INITIALIZED,
+                   "Failed to get remote address, socket not initializaed");
+      return NULL;
+    }
   else
     return g_socket_get_remote_address (self->priv->socket, error);
 }
@@ -1240,7 +1248,13 @@ evd_socket_get_local_address (EvdSocket  *self, GError **error)
   g_return_val_if_fail (EVD_IS_SOCKET (self), NULL);
 
   if (self->priv->socket == NULL)
-    return NULL;
+    {
+      g_set_error (error,
+                   G_IO_ERROR,
+                   G_IO_ERROR_NOT_INITIALIZED,
+                   "Failed to get local address, socket not initializaed");
+      return NULL;
+    }
   else
     return g_socket_get_local_address (self->priv->socket, error);
 }
@@ -1324,28 +1338,29 @@ evd_socket_connect_to (EvdSocket           *self,
                        gpointer             user_data)
 {
   GError *error = NULL;
+  GSimpleAsyncResult *res;
 
   g_return_if_fail (EVD_IS_SOCKET (self));
   g_return_if_fail (address != NULL);
 
-  self->priv->async_result =
-    g_simple_async_result_new (G_OBJECT (self),
-                               callback,
-                               user_data,
-                               evd_socket_connect_addr);
+  res = g_simple_async_result_new (G_OBJECT (self),
+                                   callback,
+                                   user_data,
+                                   evd_socket_connect_addr);
 
   if (! evd_socket_check_availability (self, &error))
     {
-      g_simple_async_result_set_from_error (self->priv->async_result, error);
+      g_simple_async_result_set_from_error (res, error);
       g_error_free (error);
 
-      g_simple_async_result_complete_in_idle (self->priv->async_result);
-      g_object_unref (self->priv->async_result);
-      self->priv->async_result = NULL;
+      g_simple_async_result_complete_in_idle (res);
+      g_object_unref (res);
 
       return;
     }
 
+  self->priv->async_result = res;
+
   self->priv->has_pending = TRUE;
 
   evd_socket_set_status (self, EVD_SOCKET_STATE_RESOLVING);
@@ -1456,26 +1471,28 @@ evd_socket_listen (EvdSocket           *self,
                    gpointer             user_data)
 {
   GError *error = NULL;
+  GSimpleAsyncResult *res;
 
   g_return_if_fail (EVD_IS_SOCKET (self));
 
-  self->priv->async_result = g_simple_async_result_new (G_OBJECT (self),
-                                                        callback,
-                                                        user_data,
-                                                        evd_socket_listen);
+  res = g_simple_async_result_new (G_OBJECT (self),
+                                   callback,
+                                   user_data,
+                                   evd_socket_listen);
 
   if (! evd_socket_check_availability (self, &error))
     {
-      g_simple_async_result_set_from_error (self->priv->async_result, error);
+      g_simple_async_result_set_from_error (res, error);
       g_error_free (error);
 
-      g_simple_async_result_complete_in_idle (self->priv->async_result);
-      g_object_unref (self->priv->async_result);
-      self->priv->async_result = NULL;
+      g_simple_async_result_complete_in_idle (res);
+      g_object_unref (res);
 
       return;
     }
 
+  self->priv->async_result = res;
+
   self->priv->has_pending = TRUE;
 
   evd_socket_set_status (self, EVD_SOCKET_STATE_RESOLVING);
@@ -1541,26 +1558,28 @@ evd_socket_bind (EvdSocket           *self,
                  gpointer             user_data)
 {
   GError *error = NULL;
+  GSimpleAsyncResult *res;
 
   g_return_if_fail (EVD_IS_SOCKET (self));
 
-  self->priv->async_result = g_simple_async_result_new (G_OBJECT (self),
-                                                        callback,
-                                                        user_data,
-                                                        evd_socket_bind);
+  res = g_simple_async_result_new (G_OBJECT (self),
+                                   callback,
+                                   user_data,
+                                   evd_socket_bind);
 
   if (! evd_socket_check_availability (self, &error))
     {
-      g_simple_async_result_set_from_error (self->priv->async_result, error);
+      g_simple_async_result_set_from_error (res, error);
       g_error_free (error);
 
-      g_simple_async_result_complete_in_idle (self->priv->async_result);
-      g_object_unref (self->priv->async_result);
-      self->priv->async_result = NULL;
+      g_simple_async_result_complete_in_idle (res);
+      g_object_unref (res);
 
       return;
     }
 
+  self->priv->async_result = res;
+
   self->priv->has_pending = TRUE;
 
   evd_socket_set_status (self, EVD_SOCKET_STATE_RESOLVING);
@@ -1588,3 +1607,41 @@ evd_socket_bind_finish (EvdSocket     *self,
   else
     return FALSE;
 }
+
+gchar *
+evd_socket_get_remote_address_str (EvdSocket *self, gsize *len, GError **error)
+{
+  gchar *result = NULL;
+  GSocketAddress *sock_addr;
+  GInetAddress *inet_addr;
+
+  g_return_val_if_fail (EVD_IS_SOCKET (self), NULL);
+
+  sock_addr = evd_socket_get_remote_address (self, error);
+  if (sock_addr == NULL)
+    return NULL;
+
+#ifdef HAVE_GIO_UNIX
+  if (self->priv->family == G_SOCKET_FAMILY_UNIX)
+    {
+      result =
+       g_strdup (g_unix_socket_address_get_path (G_UNIX_SOCKET_ADDRESS (sock_addr)));
+
+      if (len != NULL)
+        *len = g_unix_socket_address_get_path_len (G_UNIX_SOCKET_ADDRESS (sock_addr));
+
+      return result;
+    }
+#endif
+
+  inet_addr = g_inet_socket_address_get_address (G_INET_SOCKET_ADDRESS (sock_addr));
+
+  result = g_inet_address_to_string (inet_addr);
+
+  if (len != NULL)
+    *len = strlen (result);
+
+  g_object_unref (sock_addr);
+
+  return result;
+}
