@@ -3,7 +3,7 @@
  *
  * EventDance, Peer-to-peer IPC library <http://eventdance.org>
  *
- * Copyright (C) 2009/2010, Igalia S.L.
+ * Copyright (C) 2009-2013, Igalia S.L.
  *
  * Authors:
  *   Eduardo Lima Mitev <elima@igalia.com>
@@ -26,9 +26,9 @@
 #include <glib-object.h>
 #include <gio/gio.h>
 
-#include <evd-utils.h>
-#include <evd-peer-manager.h>
-#include <evd-peer.h>
+#include "evd-utils.h"
+#include "evd-peer-manager.h"
+#include "evd-peer.h"
 
 G_BEGIN_DECLS
 
@@ -158,6 +158,9 @@ gboolean        evd_transport_open_finish                   (EvdTransport  *self
                                                              GAsyncResult  *result,
                                                              GError       **error);
 
+/* defines here get_transport() method of EvdPeer to avoid cyclic dependency */
+EvdTransport *  evd_peer_get_transport                      (EvdPeer *self);
+
 G_END_DECLS
 
 #endif /* __EVD_TRANSPORT_H__ */
