@@ -214,6 +214,8 @@ evd_web_service_respond_cors_preflight (EvdWebService     *self,
                   NULL,
                   0,
                   NULL);
+
+  soup_message_headers_free (res_headers);
 }
 
 static gboolean
@@ -294,6 +296,8 @@ evd_web_service_conn_on_headers_read (GObject      *obj,
 
       g_error_free (error);
     }
+
+  g_object_unref (self);
 }
 
 static void
@@ -317,6 +321,7 @@ evd_web_service_connection_accepted (EvdService *service, EvdConnection *conn)
     }
   else
     {
+      g_object_ref (self);
       evd_http_connection_read_request_headers (EVD_HTTP_CONNECTION (conn),
                                            NULL,
                                            evd_web_service_conn_on_headers_read,
@@ -451,17 +456,6 @@ evd_web_service_respond_internal (EvdWebService       *self,
   else
     ver = evd_http_message_get_version (EVD_HTTP_MESSAGE (request));
 
-  if (evd_http_connection_get_keepalive (conn))
-    {
-      if (headers == NULL)
-        {
-          headers = soup_message_headers_new (SOUP_MESSAGE_HEADERS_RESPONSE);
-          free_headers = TRUE;
-        }
-
-      soup_message_headers_replace (headers, "Connection", "keep-alive");
-    }
-
   /* check cross origin */
   if (status_code != SOUP_STATUS_FORBIDDEN &&
       request != NULL &&
@@ -493,7 +487,7 @@ evd_web_service_respond_internal (EvdWebService       *self,
                                    headers,
                                    content,
                                    size,
-                                   ! evd_http_connection_get_keepalive (conn),
+                                   FALSE,
                                    error))
     {
       EVD_WEB_SERVICE_GET_CLASS (self)->flush_and_return_connection (self, conn);
