@@ -3,7 +3,7 @@
  *
  * EventDance, Peer-to-peer IPC library <http://eventdance.org>
  *
- * Copyright (C) 2009/2010/2011, Igalia S.L.
+ * Copyright (C) 2009-2013, Igalia S.L.
  *
  * Authors:
  *   Eduardo Lima Mitev <elima@igalia.com>
@@ -25,10 +25,10 @@
 
 #include <libsoup/soup-headers.h>
 
-#include <evd-service.h>
-#include <evd-http-connection.h>
-#include <evd-http-request.h>
-#include <evd-utils.h>
+#include "evd-service.h"
+#include "evd-http-connection.h"
+#include "evd-http-request.h"
+#include "evd-utils.h"
 
 G_BEGIN_DECLS
 
