@@ -3,7 +3,7 @@
  *
  * EventDance, Peer-to-peer IPC library <http://eventdance.org>
  *
- * Copyright (C) 2009/2010, Igalia S.L.
+ * Copyright (C) 2009-2013, Igalia S.L.
  *
  * Authors:
  *   Eduardo Lima Mitev <elima@igalia.com>
@@ -23,9 +23,9 @@
 #ifndef __EVD_WEB_TRANSPORT_SERVER_H__
 #define __EVD_WEB_TRANSPORT_SERVER_H__
 
-#include <evd-web-dir.h>
-#include <evd-web-selector.h>
-#include <evd-peer.h>
+#include "evd-web-dir.h"
+#include "evd-web-selector.h"
+#include "evd-peer.h"
 
 G_BEGIN_DECLS
 
