@@ -582,7 +582,8 @@ Evd.Object.extend (Evd.WebTransport.prototype, {
         };
 
         var hsData = {
-            mechanisms: this._availableMechs
+            mechanisms: this._availableMechs,
+            url: this._addr
         };
 
         this._handshaking = true;
@@ -617,7 +618,7 @@ Evd.Object.extend (Evd.WebTransport.prototype, {
     },
 
     _flush: function () {
-        if (this._transport.canSend ()) {
+        if (this._transport && this._transport.canSend ()) {
             this._flushBuf = this._outBuf;
             this._outBuf = [];
             this._transport.send (this._flushBuf);
@@ -659,8 +660,10 @@ Evd.Object.extend (Evd.WebTransport.prototype, {
 
             this._dispatching = false;
 
-            if (! this._flushing ())
+            if (! this._flushing ()) {
                 this._retryCount = 0;
+                this._flush ();
+            }
 
         }
         else {
